"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fcl = tslib_1.__importStar(require("@onflow/fcl"));
const logger_1 = require("../../utils/logger");
const read_files_1 = require("../../utils/file/read-files");
const select_template_files_1 = require("../../questions/audit/select-template-files");
const input_account_1 = require("../../questions/audit/input-account");
const key_id_1 = require("../../questions/audit/key-id");
const sign_algo_1 = require("../../questions/audit/sign-algo");
const hash_algo_1 = require("../../questions/audit/hash-algo");
const input_private_key_1 = require("../../questions/audit/input-private-key");
const input_network_1 = require("../../questions/audit/input-network");
const audit_monad_1 = require("../../utils/audit/audit-monad");
const splashscreen_1 = require("../../utils/splashscreen");
const sign_send_audit_transaction_1 = require("../../utils/audit/sign-send-audit-transaction");
class Generate extends core_1.Command {
    async run() {
        var _a;
        const { argv, args, flags } = await this.parse(Generate);
        const { path } = args;
        const a = "a";
        (0, splashscreen_1.auditSplashTitle)();
        logger_1.logger.warn("⚠️  Warning: The FLIX CLI is currently in early alpha. Please report any bugs by opening an issue here: https://github.com/onflow/flow-interaction-template-tools/issues/new");
        let files = await (0, read_files_1.readFiles)(path);
        const flowJSONFiles = await (0, read_files_1.readFiles)(flags.flowJsonPath || "flow.json");
        const flowJSON = flowJSONFiles[0] ?
            JSON.parse(flowJSONFiles[0].content) :
            null;
        if (flowJSON === null) {
            logger_1.logger.error("❌ Error: No flow.json file found.");
            return;
        }
        // If more than one file found, ask which files they want to generate templates for.
        files = await (0, select_template_files_1.question)(files);
        for (let i = 0; i < files.length; i++) {
            const file = files[i];
            const template = JSON.parse(file.content);
            logger_1.logger.default(`\n🌱 [Audit ${i + 1} / ${files.length}] ⚖️  Generating audit for ${file.path}\n\n----${file.path}----`);
            logger_1.logger.default(file.content);
            logger_1.logger.default("----\n");
            let auditMonad = (0, audit_monad_1.generateAuditMonad)(file, flowJSON);
            const inputs = [
                input_account_1.question,
                input_network_1.question,
                input_private_key_1.question,
                key_id_1.question,
                sign_algo_1.question,
                hash_algo_1.question,
            ];
            // DO BETTER
            if (auditMonad.signerNetwork === "mainnet") {
                await fcl
                    .config()
                    .put("0xFlowInteractionTemplateAudit", "0xfd100e39d50a13e6");
            }
            else if (auditMonad.signerNetwork === "testnet") {
                await fcl
                    .config()
                    .put("0xFlowInteractionTemplateAudit", "0xf78bfc12d0a786dc");
            }
            auditMonad = await inputs.reduce(async (am, input) => input(await am), Promise.resolve(auditMonad));
            auditMonad = {
                ...auditMonad,
                signerAddress: fcl.withPrefix((_a = auditMonad.account) === null || _a === void 0 ? void 0 : _a.address),
                signerKeyId: auditMonad.keyId,
            };
            const auditTxId = await (0, sign_send_audit_transaction_1.signSendAuditTransaction)(auditMonad);
            logger_1.logger.default("\n🌱 Audit TxID: \n\n", JSON.stringify(auditTxId, null, 2), "\n");
            logger_1.logger.default("\n🌱 Audit transaction Submitted, awaiting Execution");
            await new Promise((res, rej) => {
                fcl
                    .config()
                    .overload({ "accessNode.api": auditMonad.accessNodeAPI }, async () => fcl.tx(auditTxId).subscribe(tx => {
                    if (tx.status === 3) {
                        logger_1.logger.default("\n🌱 Audit transaction Executed, awaiting Sealing");
                    }
                    if (tx.status >= 4) {
                        logger_1.logger.default("\n🌱 Audit transaction Sealed");
                        res(null);
                    }
                }));
            });
        }
        logger_1.logger.default("\n🌱🎉 Interaction audit complete!\n");
    }
}
exports.default = Generate;
Generate.description = "Audit Interaction Template json files.";
Generate.examples = ["$ flowplate audit ./src/cadence"];
Generate.flags = {
    flowJsonPath: core_1.Flags.string({
        char: "f",
        summary: "Path to a flow.json configuration file.",
    }),
};
Generate.args = [
    {
        name: "path",
        description: "Path to a folder or individual Interaction Template JSON file.",
        required: true,
    },
];
