"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const logger_1 = require("../../utils/logger");
const read_files_1 = require("../../utils/file/read-files");
const write_file_1 = require("../../utils/file/write-file");
const select_cdc_files_1 = require("../../questions/generate/select-cdc-files");
const interaction_type_1 = require("../../questions/generate/interaction-type");
const interface_id_1 = require("../../questions/generate/interface-id");
const messages_1 = require("../../questions/generate/messages");
const arguments_1 = require("../../questions/generate/arguments");
const generate_template_1 = require("../../utils/template/generate-template");
const template_monad_1 = require("../../utils/template/template-monad");
const splashscreen_1 = require("../../utils/splashscreen");
const generate_pins_1 = require("../../questions/generate/generate-pins");
class Generate extends core_1.Command {
    async run() {
        const { argv, args, flags } = await this.parse(Generate);
        const { path } = args;
        (0, splashscreen_1.generateSplashTitle)();
        logger_1.logger.warn("⚠️  Warning: The FLIX CLI is currently in early alpha. Please report any bugs by opening an issue here: https://github.com/onflow/flow-interaction-template-tools/issues/new");
        let files = await (0, read_files_1.readFiles)(path);
        const flowJSONFiles = await (0, read_files_1.readFiles)(flags.flowJsonPath || "flow.json");
        const flowJSON = flowJSONFiles[0] ?
            JSON.parse(flowJSONFiles[0].content) :
            null;
        if (flowJSON === null) {
            logger_1.logger.error("❌ Error: No flow.json file found.");
            return;
        }
        // If more than one file found, ask which files they want to generate templates for.
        files = await (0, select_cdc_files_1.question)(files);
        for (let i = 0; i < files.length; i++) {
            const file = files[i];
            logger_1.logger.default(`\n🌱 [Template ${i + 1} / ${files.length}] ⚙️  Generating template for ${file.path}\n\n----${file.path}----`);
            logger_1.logger.default(file.content);
            logger_1.logger.default("----\n");
            let templateMonad = (0, template_monad_1.generateTemplateMonad)(file, flowJSON);
            const questions = [
                interaction_type_1.question,
                messages_1.question,
                arguments_1.question,
                generate_pins_1.generatePins,
                interface_id_1.question,
            ];
            templateMonad = await questions.reduce(async (tm, question) => question(await tm), Promise.resolve(templateMonad));
            const template = await (0, generate_template_1.generateTemplate)(templateMonad);
            logger_1.logger.default("\n🌱 Template: \n\n", JSON.stringify(template, null, 2), "\n");
            const filePathLessCDC = file.path
                .split(".")
                .slice(0, file.path.split(".").length - 1)
                .map(s => (s === "" ? "." : s))
                .join("");
            const filePathParts = [filePathLessCDC];
            filePathParts.push("template", "json");
            const templateFilePath = filePathParts.join(".");
            await (0, write_file_1.writeFile)(templateFilePath, JSON.stringify(template, null, 2));
            logger_1.logger.default(`\n🌱 Saved interaction template to ${templateFilePath}\n`);
        }
        logger_1.logger.default("\n🌱🎉 Interaction template generation complete!\n");
    }
}
exports.default = Generate;
Generate.description = "Generate Interaction Templates from .cdc files.";
Generate.examples = ["$ flowplate generate ./src/cadence"];
Generate.flags = {
    flowJsonPath: core_1.Flags.string({
        char: "f",
        summary: "Path to a flow.json configuration file.",
    }),
};
Generate.args = [
    {
        name: "path",
        description: "Path to a folder or individual CDC file.",
        required: true,
    },
];
