"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const logger_1 = require("../../utils/logger");
const read_files_1 = require("../../utils/file/read-files");
const express_1 = tslib_1.__importDefault(require("express"));
const cors_1 = tslib_1.__importDefault(require("cors"));
class Generate extends core_1.Command {
    async run() {
        const { argv, args, flags } = await this.parse(Generate);
        const { path, port } = args;
        const files = await (0, read_files_1.readFiles)(path);
        const parsedFiles = files
            .map(file => {
            try {
                const json = JSON.parse(file.content);
                return json;
            }
            catch {
                return null;
            }
        })
            .filter(file => file !== null);
        logger_1.logger.default("\n--- 🔎 Finding InteractionTemplate ---\n");
        let templates = parsedFiles.filter(file => {
            if ((file === null || file === void 0 ? void 0 : file.f_type) === "InteractionTemplate") {
                logger_1.logger.default(`🌱 Serving InteractionTemplate id = ${file === null || file === void 0 ? void 0 : file.id}`);
                return true;
            }
            return false;
        });
        if (templates.length === 0)
            logger_1.logger.default("\n⚠️  No InteractionTemplate found\n");
        templates = Object.fromEntries(templates.map(curr => [curr.id, curr]));
        const app = (0, express_1.default)();
        app.use((0, cors_1.default)());
        app.get("/templates/:id", function (req, res) {
            const id = req.params.id;
            const foundTemplate = templates[id];
            if (foundTemplate) {
                logger_1.logger.default(`🌱✅ Request: http://localhost:${port}/templates/${id} => [200] InteractionTemplate with id = ${id}`);
                res.json(foundTemplate);
            }
            else {
                logger_1.logger.default(`🌱❌ Request: http://localhost:${port}/templates/${id} => [404] InteractionTemplate with id = ${id} not found`);
                res.status(404).json({ error: "Cannot find template with id = " + id });
            }
        });
        app.listen(Number(port));
        logger_1.logger.default(`\n---- 🌱🚀 Server running on port ${port} ! ----\n`);
        logger_1.logger.default(`🌱 http://localhost:${port}/templates/:template_id => InteractionTemplate`);
        logger_1.logger.default("---- Requests ----\n");
    }
}
exports.default = Generate;
Generate.description = "Serve Interaction Templates queryable by id.";
Generate.examples = ["$ flowplate serve ./src/templates"];
Generate.flags = {};
Generate.args = [
    {
        name: "path",
        description: "Path to a folder or individual Interaction Template JSON file.",
        required: true,
    },
    {
        name: "port",
        description: "Port to run on.",
        required: false,
    },
];
