"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fcl = tslib_1.__importStar(require("@onflow/fcl"));
const logger_1 = require("../../utils/logger");
const read_files_1 = require("../../utils/file/read-files");
const network_1 = require("../../questions/verify/network");
const splashscreen_1 = require("../../utils/splashscreen");
class Generate extends core_1.Command {
    async run() {
        var _a;
        const { argv, args, flags } = await this.parse(Generate);
        const { templatePath, auditorAddress } = args;
        (0, splashscreen_1.verifySplashTitle)();
        logger_1.logger.warn("⚠️  Warning: The FLIX CLI is currently in early alpha. Please report any bugs by opening an issue here: https://github.com/onflow/flow-interaction-template-tools/issues/new");
        const templateFiles = await (0, read_files_1.readFiles)(templatePath);
        if (templateFiles.length > 1)
            return; // Cannot audit more than one template at a time
        const flowJSONFiles = await (0, read_files_1.readFiles)(flags.flowJsonPath || "flow.json");
        const flowJSON = flowJSONFiles[0] ?
            JSON.parse(flowJSONFiles[0].content) :
            null;
        const templateFile = templateFiles[0];
        const template = JSON.parse(templateFile.content);
        logger_1.logger.default(`\n🌱 Verifying audit by auditor ${auditorAddress} for ${templateFile.path}\n\n----${templateFile.path}----`);
        logger_1.logger.default(templateFile.content);
        logger_1.logger.default("----\n\n");
        logger_1.logger.default("\n🌱 Collecting network to perform audit\n");
        const network = await (0, network_1.question)(flowJSON);
        const accessNodeAPI = (_a = flowJSON === null || flowJSON === void 0 ? void 0 : flowJSON.networks) === null || _a === void 0 ? void 0 : _a[network];
        await fcl.config().put("accessNode.api", accessNodeAPI);
        let isVerified = false;
        try {
            const audits = await fcl.InteractionTemplateUtils.getInteractionTemplateAudits({
                template,
                auditors: [fcl.withPrefix(auditorAddress)],
            });
            isVerified = Object.keys(audits).includes(fcl.withPrefix(auditorAddress));
        }
        catch {
            logger_1.logger.default("\n⚠️  Verify \n\nERROR");
            logger_1.logger.default(`\n💡 Ensure Auditor address is valid for network=${network}\n`);
            return;
        }
        logger_1.logger.default("\n🌱 Verify \n\n", isVerified ? "SUCCESS" : "FAIL", "\n");
        logger_1.logger.default("\n🌱🎉 Audit verification complete!\n");
    }
}
exports.default = Generate;
Generate.description = "Verify that an Interaction Template has been audited by an Auditor.";
Generate.examples = [
    "$ flowplate verify \"./src/cadence/template.json\" \"0xABC123DEF456 ",
];
Generate.flags = {
    flowJsonPath: core_1.Flags.string({
        char: "f",
        summary: "Path to a flow.json configuration file.",
    }),
};
Generate.args = [
    {
        name: "templatePath",
        description: "Path to an individual Interaction Template JSON file.",
        required: true,
    },
    {
        name: "auditorAddress",
        description: "Address of an Auditor to verify if they have audited the Interaction Template.",
        required: true,
    },
];
