"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.question = exports.parseArgs = void 0;
const tslib_1 = require("tslib");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
// import * as fcl from "@onflow/fcl"
// import {exec} from "child_process"
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const bcp47_tags_1 = require("../../utils/bcp47-tags");
const logger_1 = require("../../utils/logger");
function parseArgs(file) {
    const argsList_RegEx = /(pub fun main|transaction)\(((\w+: \w+)(, )?)+\)/g;
    const parsedArgsRegExResult = argsList_RegEx.exec(file === null || file === void 0 ? void 0 : file.content);
    const parsedArgsList = parsedArgsRegExResult ?
        parsedArgsRegExResult[0] :
        null;
    const parsedArgsFromCDC = parsedArgsList ?
        parsedArgsList.match(/(\w+: \w+)/g) :
        null;
    if (!parsedArgsFromCDC)
        return null;
    const parsedArgs = parsedArgsFromCDC.map(function (parsedArgFromCDC) {
        const nameAndType = parsedArgFromCDC.match(/\w+/g);
        if (!nameAndType)
            return null;
        return {
            name: nameAndType[0],
            type: nameAndType[1],
        };
    });
    return parsedArgs.filter(a => a !== null);
}
exports.parseArgs = parseArgs;
async function question(templateMonad) {
    var _a;
    logger_1.logger.default("\n🌱 Collecting argument messages\n");
    const file = templateMonad.file;
    const messages = {};
    const parsedArgs = parseArgs(file);
    if (!parsedArgs)
        return messages;
    let argIndex = 0;
    for (const arg of parsedArgs) {
        const messageTranslations = {};
        let continueGatheringMessages = true;
        while (continueGatheringMessages) {
            let currMessageKey = "";
            await inquirer_1.default
                .prompt([
                {
                    type: "input",
                    message: `[${file === null || file === void 0 ? void 0 : file.path}] Key for the message (Hint: "title", "description") for argument ${chalk_1.default.whiteBright.bold.inverse(`- (${arg === null || arg === void 0 ? void 0 : arg.name}: ${arg === null || arg === void 0 ? void 0 : arg.type}) -`)}:`,
                    name: "msgKey",
                    validate(answer) {
                        const ans = String(answer);
                        if (answer.length === 0)
                            return "Key must be at least one character.";
                        if (messages[answer])
                            return "Cannot use the same key twice.";
                        return true;
                    },
                },
            ])
                .then(answers => {
                currMessageKey = answers.msgKey;
            });
            let continueGatheringMessageTranslations = true;
            while (continueGatheringMessageTranslations) {
                let currMessageLangTag = "";
                await inquirer_1.default
                    .prompt([
                    {
                        type: "list",
                        message: `[${file === null || file === void 0 ? void 0 : file.path}] Language translation for ${chalk_1.default.whiteBright.bold.inverse(`- ${currMessageKey} -`)} for argument ${chalk_1.default.whiteBright.bold.inverse(`- (${arg === null || arg === void 0 ? void 0 : arg.name}: ${arg === null || arg === void 0 ? void 0 : arg.type}) -`)}:`,
                        name: "msgLangTag",
                        choices: bcp47_tags_1.tags.map(tag => ({
                            name: tag,
                            value: tag,
                        })),
                        validate(answer) {
                            if (messages[answer])
                                return `Cannot use the same language translation twice for ${chalk_1.default.whiteBright.bold.inverse(`- ${currMessageKey} -`)} for argument ${chalk_1.default.whiteBright.bold.inverse(`- (${arg === null || arg === void 0 ? void 0 : arg.name}: ${arg === null || arg === void 0 ? void 0 : arg.type}) -`)}.`;
                            return true;
                        },
                    },
                ])
                    .then(answers => {
                    currMessageLangTag = answers.msgLangTag;
                });
                let currMessageLangTagTranslation = "";
                await inquirer_1.default
                    .prompt([
                    {
                        type: "input",
                        message: `[${file === null || file === void 0 ? void 0 : file.path}] Message content for ${chalk_1.default.whiteBright.bold.inverse(`- ${currMessageLangTag} -`)} translation for ${chalk_1.default.whiteBright.bold.inverse(`- ${currMessageKey} -`)} for argument ${chalk_1.default.whiteBright.bold.inverse(`- (${arg === null || arg === void 0 ? void 0 : arg.name}: ${arg === null || arg === void 0 ? void 0 : arg.type}) -`)}:`,
                        name: "msgLangTagTranslation",
                        validate(answer) {
                            if (answer.length === 0)
                                return "Translation must be at least one character.";
                            return true;
                        },
                    },
                ])
                    .then(answers => {
                    currMessageLangTagTranslation = answers.msgLangTagTranslation;
                });
                messageTranslations[currMessageLangTag] = currMessageLangTagTranslation;
                await inquirer_1.default
                    .prompt([
                    {
                        type: "confirm",
                        message: `[${file === null || file === void 0 ? void 0 : file.path}] Continue submitting message translations for ${chalk_1.default.whiteBright.bold.inverse(`- ${currMessageKey} -`)} for argument ${chalk_1.default.whiteBright.bold.inverse(`- (${arg === null || arg === void 0 ? void 0 : arg.name}: ${arg === null || arg === void 0 ? void 0 : arg.type}) -`)}?:`,
                        name: "continueMessageTranslations",
                        validate(answer) {
                            return true;
                        },
                    },
                ])
                    .then(answers => {
                    continueGatheringMessageTranslations =
                        answers.continueMessageTranslations;
                });
            }
            messages[arg === null || arg === void 0 ? void 0 : arg.name] = {
                ...messages[arg === null || arg === void 0 ? void 0 : arg.name],
                index: argIndex,
                type: arg === null || arg === void 0 ? void 0 : arg.type,
                messages: {
                    ...(_a = messages[arg === null || arg === void 0 ? void 0 : arg.name]) === null || _a === void 0 ? void 0 : _a.messages,
                    [currMessageKey]: {
                        i18n: {
                            ...messageTranslations,
                        },
                    },
                },
            };
            await inquirer_1.default
                .prompt([
                {
                    type: "confirm",
                    message: `[${file === null || file === void 0 ? void 0 : file.path}] Continue submitting messages for ${chalk_1.default.whiteBright.bold.inverse(`- (${arg === null || arg === void 0 ? void 0 : arg.name}: ${arg === null || arg === void 0 ? void 0 : arg.type}) -`)}?:`,
                    name: "continueMessages",
                    validate(answer) {
                        return true;
                    },
                },
            ])
                .then(answers => {
                continueGatheringMessages = answers.continueMessages;
            });
            argIndex += 1;
        }
    }
    return {
        ...templateMonad,
        args: messages,
    };
}
exports.question = question;
