"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generatePins = void 0;
const tslib_1 = require("tslib");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const core_1 = require("@oclif/core");
const fcl = tslib_1.__importStar(require("@onflow/fcl"));
const logger_1 = require("../../utils/logger");
async function inputAddressForNetwork(file, address, network) {
    return inquirer_1.default
        .prompt([
        {
            type: "input",
            message: `[${file === null || file === void 0 ? void 0 : file.path}] Input account address for ${address} on ${network}:`,
            name: "address",
            validate(answer) {
                if (fcl.sansPrefix(answer).length !== 16) {
                    return "Account address must be 16 characters long";
                }
                return true;
            },
        },
    ])
        .then(answers => {
        return fcl.withPrefix(answers.address);
    });
}
function findImports(cadence, isPlaceholder = false) {
    const iports = [];
    if (!cadence || cadence === "")
        return iports;
    const importsReg = /import \w+ from 0x\w+/g;
    const fileImports = cadence.match(importsReg) || [];
    for (const fileImport of fileImports) {
        const importReg = /import (\w+) from (0x\w+)/g;
        const fileiport = importReg.exec(fileImport);
        if (fileiport) {
            if (isPlaceholder) {
                iports.push({
                    addressPlaceholder: fileiport[2],
                    contractName: fileiport[1],
                });
            }
            else {
                iports.push({
                    address: fileiport[2],
                    contractName: fileiport[1],
                });
            }
        }
    }
    return iports;
}
async function generatePins(templateMonad) {
    var _a, _b, _c, _d;
    logger_1.logger.default("\n🌱 Generating dependency pins\n");
    const file = templateMonad.file;
    const addressMemo = {
        testnet: {},
        mainnet: {},
        emulator: {},
    };
    const pins = {};
    const iports = findImports(file === null || file === void 0 ? void 0 : file.content, true);
    if (iports.length === 0)
        return {
            ...templateMonad,
            dependencies: pins,
        };
    const networks = ["testnet", "mainnet", "emulator"];
    for (const network of networks) {
        let doesUserWantToGeneratePin = true;
        await inquirer_1.default
            .prompt([
            {
                type: "confirm",
                message: `[${file === null || file === void 0 ? void 0 : file.path}] Do you want to generate a dependency pin for ${network}? :`,
                name: "toGeneratePin",
                default: true,
                validate(answer) {
                    return true;
                },
            },
        ])
            .then(answers => {
            doesUserWantToGeneratePin = answers.toGeneratePin;
        });
        if (!doesUserWantToGeneratePin)
            continue;
        logger_1.logger.default(`🌱 Generating dependency pin for ${network}...`);
        const networkIports = iports.map(iport => ({
            ...iport,
        }));
        for (const iport of networkIports) {
            if (!((_a = addressMemo === null || addressMemo === void 0 ? void 0 : addressMemo[network]) === null || _a === void 0 ? void 0 : _a[iport === null || iport === void 0 ? void 0 : iport.addressPlaceholder])) {
                const addr = await inputAddressForNetwork(file, iport === null || iport === void 0 ? void 0 : iport.addressPlaceholder, network);
                addressMemo[network][iport === null || iport === void 0 ? void 0 : iport.addressPlaceholder] = addr;
            }
            iport.address = addressMemo[network][iport === null || iport === void 0 ? void 0 : iport.addressPlaceholder];
        }
        const accessNodeAPI = (_c = (_b = templateMonad === null || templateMonad === void 0 ? void 0 : templateMonad.flowJSON) === null || _b === void 0 ? void 0 : _b.networks) === null || _c === void 0 ? void 0 : _c[network];
        await fcl.config().put("accessNode.api", accessNodeAPI);
        const latestSealedBlock = await fcl.block({ sealed: true });
        const latestBlockPin = latestSealedBlock === null || latestSealedBlock === void 0 ? void 0 : latestSealedBlock.height;
        for (const networkIport of networkIports) {
            core_1.CliUx.ux.action.start(chalk_1.default.whiteBright.bold(`🌱 Generating dependency pin for ${networkIport.addressPlaceholder} on ${network}`));
            const pin = await fcl.InteractionTemplateUtils.generateDependencyPin({
                address: networkIport.address,
                contractName: networkIport.contractName,
                blockHeight: latestBlockPin,
            });
            pins[networkIport.addressPlaceholder] = {
                ...((pins === null || pins === void 0 ? void 0 : pins[networkIport.addressPlaceholder]) || []),
                [networkIport.contractName]: {
                    ...(((_d = pins === null || pins === void 0 ? void 0 : pins[networkIport.addressPlaceholder]) === null || _d === void 0 ? void 0 : _d[networkIport.contractName]) || []),
                    [network]: {
                        address: networkIport.address,
                        contract: networkIport.contractName,
                        fq_address: `A.${networkIport.address}.${networkIport.contractName}`,
                        pin: pin,
                        pin_block_height: latestBlockPin,
                    },
                },
            };
            core_1.CliUx.ux.action.stop(chalk_1.default.whiteBright.bold("Generated!"));
        }
    }
    return {
        ...templateMonad,
        dependencies: pins,
    };
}
exports.generatePins = generatePins;
