"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.question = void 0;
const tslib_1 = require("tslib");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const bcp47_tags_1 = require("../../utils/bcp47-tags");
const logger_1 = require("../../utils/logger");
async function question(templateMonad) {
    logger_1.logger.default("\n🌱 Collecting template messages");
    logger_1.logger.default("🌱 A title and description are recommended\n");
    const file = templateMonad.file;
    const messages = {};
    let continueGatheringMessages = true;
    while (continueGatheringMessages) {
        let currMessageKey = "";
        await inquirer_1.default.prompt([
            {
                type: "input",
                message: `[${file === null || file === void 0 ? void 0 : file.path}] Key for the message (Hint: "title", "description"):`,
                name: "msgKey",
                validate(answer) {
                    const ans = String(answer);
                    if (answer.length === 0)
                        return "Key must be at least one character.";
                    if (messages[answer])
                        return "Cannot use the same key twice.";
                    return true;
                },
            },
        ]).then(answers => {
            currMessageKey = answers.msgKey;
        });
        const messageTranslations = {};
        let continueGatheringMessageTranslations = true;
        while (continueGatheringMessageTranslations) {
            let currMessageLangTag = "";
            await inquirer_1.default.prompt([
                {
                    type: "list",
                    message: `[${file === null || file === void 0 ? void 0 : file.path}] Language translation for ${currMessageKey}:`,
                    name: "msgLangTag",
                    choices: bcp47_tags_1.tags.map(tag => ({
                        name: tag,
                        value: tag,
                    })),
                    validate(answer) {
                        if (messages[answer])
                            return `Cannot use the same language translation twice for ${currMessageKey}.`;
                        return true;
                    },
                },
            ]).then(answers => {
                currMessageLangTag = answers.msgLangTag;
            });
            let currMessageLangTagTranslation = "";
            await inquirer_1.default.prompt([
                {
                    type: "input",
                    message: `[${file === null || file === void 0 ? void 0 : file.path}] Message content for ${currMessageLangTag} translation for ${currMessageKey}:`,
                    name: "msgLangTagTranslation",
                    validate(answer) {
                        if (answer.length === 0)
                            return "Translation must be at least one character.";
                        return true;
                    },
                },
            ]).then(answers => {
                currMessageLangTagTranslation = answers.msgLangTagTranslation;
            });
            messageTranslations[currMessageLangTag] = currMessageLangTagTranslation;
            await inquirer_1.default.prompt([
                {
                    type: "confirm",
                    message: `[${file === null || file === void 0 ? void 0 : file.path}] Continue submitting message translations for ${currMessageKey}?:`,
                    name: "continueMessageTranslations",
                    validate(answer) {
                        return true;
                    },
                },
            ]).then(answers => {
                continueGatheringMessageTranslations = answers.continueMessageTranslations;
            });
        }
        messages[currMessageKey] = {
            i18n: messageTranslations,
        };
        await inquirer_1.default.prompt([
            {
                type: "confirm",
                message: `[${file === null || file === void 0 ? void 0 : file.path}] Continue submitting messages?:`,
                name: "continueMessages",
                validate(answer) {
                    return true;
                },
            },
        ]).then(answers => {
            continueGatheringMessages = answers.continueMessages;
        });
    }
    return ({
        ...templateMonad,
        messages,
    });
}
exports.question = question;
