"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSupportedGeneratedTransactions = exports.getCollectionsCount = exports.getCollections = exports.getAllCollections = exports.getGeneratedTransaction = void 0;
const tslib_1 = require("tslib");
const fcl = tslib_1.__importStar(require("@onflow/fcl"));
const catalog_c2j_json_1 = tslib_1.__importDefault(require("./catalog_c2j.json"));
async function getGeneratedTransaction(tx, collectionIdentifer, vaultIdentifier, merchantAddress) {
    try {
        const scriptResult = await fcl.send([
            fcl.script(catalog_c2j_json_1.default.scripts.gen_tx),
            fcl.args([
                fcl.arg(tx, fcl.t.String),
                fcl.arg(collectionIdentifer, fcl.t.String),
                fcl.arg(vaultIdentifier, fcl.t.String),
                fcl.arg(merchantAddress, fcl.t.String)
            ])
        ]).then(fcl.decode);
        return scriptResult;
    }
    catch (e) {
        return null;
    }
}
exports.getGeneratedTransaction = getGeneratedTransaction;
async function getAllCollections() {
    const CHUNK = 50;
    const collectionCount = await getCollectionsCount();
    const catalogBatches = [];
    for (let i = 0; i < collectionCount; i += CHUNK) {
        if (i + CHUNK > collectionCount) {
            catalogBatches.push([String(i), String(collectionCount)]);
        }
        else {
            catalogBatches.push([String(i), String(i + CHUNK)]);
        }
    }
    let collections = {};
    for (const catalogBatch of catalogBatches) {
        const currentBatch = await getCollections(catalogBatch) || [];
        collections = {
            ...currentBatch,
            ...collections
        };
    }
    return collections;
}
exports.getAllCollections = getAllCollections;
async function getCollections(batch) {
    try {
        const scriptResult = await fcl.send([
            fcl.script(catalog_c2j_json_1.default.scripts.get_nft_catalog),
            fcl.args([
                fcl.arg(batch, fcl.t.Optional(fcl.t.Array(fcl.t.UInt64)))
            ])
        ]).then(fcl.decode);
        return scriptResult;
    }
    catch (e) {
        console.error(e);
        return null;
    }
}
exports.getCollections = getCollections;
async function getCollectionsCount() {
    try {
        const scriptResult = await fcl.send([
            fcl.script(catalog_c2j_json_1.default.scripts.get_nft_catalog_count),
            fcl.args([])
        ]).then(fcl.decode);
        return scriptResult;
    }
    catch (e) {
        console.error(e);
        return null;
    }
}
exports.getCollectionsCount = getCollectionsCount;
async function getSupportedGeneratedTransactions() {
    try {
        const scriptResult = await fcl.send([
            fcl.script(catalog_c2j_json_1.default.scripts.get_supported_generated_transactions),
            fcl.args([])
        ]).then(fcl.decode);
        return scriptResult;
    }
    catch (e) {
        console.error(e);
        return null;
    }
}
exports.getSupportedGeneratedTransactions = getSupportedGeneratedTransactions;
