"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateInteractionTemplate = void 0;
const tslib_1 = require("tslib");
// @ts-nocheck
const setup_fcl_1 = require("./setup-fcl");
const catalog_helpers_1 = require("./catalog-helpers");
const FLIX_Generators = tslib_1.__importStar(require("@onflow/interaction-template-generators"));
const interaction_template_utils_1 = require("./interaction-template-utils");
async function constructInteractionTemplate(cadence, transaction, identifier, networks, addressByNetwork = new Map()) {
    const template = await FLIX_Generators.template({
        iface: "",
        type: interaction_template_utils_1.TRANSACTION_TYPES[transaction] ?
            interaction_template_utils_1.TRANSACTION_TYPES[transaction].type : null,
        cadence: cadence,
        messages: FLIX_Generators.messages(interaction_template_utils_1.TRANSACTION_TYPES[transaction] ?
            interaction_template_utils_1.TRANSACTION_TYPES[transaction].messages({ projectName: identifier }) : []),
        args: FLIX_Generators.args(interaction_template_utils_1.TRANSACTION_TYPES[transaction] ?
            interaction_template_utils_1.TRANSACTION_TYPES[transaction].args({ projectName: identifier }) : []),
        dependencies: FLIX_Generators.dependencies(Array.from(addressByNetwork).map(([key, value]) => FLIX_Generators.dependency({
            addressPlaceholder: `0x${key}`,
            contracts: [
                FLIX_Generators.dependencyContract({
                    contractName: key,
                    networks: networks.map(networkOption => FLIX_Generators.dependencyContractByNetwork({
                        network: networkOption,
                        contractName: key,
                        address: value.get(networkOption),
                        fqAddress: `A.${value.get(networkOption)}.${key}`,
                    }, (() => {
                        if (networkOption === "testnet") {
                            return { "node": "https://rest-testnet.onflow.org" };
                        }
                        if (networkOption === "mainnet") {
                            return { "node": "https://rest-mainnet.onflow.org" };
                        }
                        return {};
                    })()))
                })
            ]
        })))
    });
    return template;
}
async function generateInteractionTemplate(transaction, identifier, networks) {
    var _a;
    try {
        // { network: address }
        const cadenceByNetwork = new Map();
        // { placholder: { network: address } }
        const addressByNetwork = new Map();
        let cadence = {};
        for (let network of networks) {
            if (network === "mainnet") {
                (0, setup_fcl_1.setupMainnet)();
            }
            if (network === "testnet") {
                (0, setup_fcl_1.setupTestnet)();
            }
            const res = await (0, catalog_helpers_1.getGeneratedTransaction)(transaction, identifier, "flow", "0x9999999999999999");
            if (!res) {
                cadence[network] = null;
                continue;
            }
            cadenceByNetwork.set(network, res);
            let importsReg = /import (\w|,| )+ from 0x\w+/g;
            let fileImports = res.match(importsReg) || [];
            for (let fileImport of fileImports) {
                let placeholder = "";
                let address = "";
                fileImport = fileImport.replace(/(?:import ((\w|,| )+) from (0x\w+))/g, function (...args) {
                    address = args[3];
                    placeholder = args[1];
                    return "import " + placeholder + " from 0x" + placeholder;
                });
                addressByNetwork.get(placeholder) ?
                    (_a = addressByNetwork.get(placeholder)) === null || _a === void 0 ? void 0 : _a.set(network, address)
                    :
                        addressByNetwork.set(placeholder, (new Map()).set(network, address));
            }
            cadence[network] = res.replace(/(?:import ((\w|,| )+) from (0x\w+))/g, function (...args) {
                return "import " + args[1] + " from 0x" + args[1];
            });
        }
        // Check if cadence bodies match
        let doCadenceBodiesMatch = true;
        addressByNetwork.forEach((networkAddresses) => {
            let count = 0;
            for (const networkAddress of networkAddresses)
                count++;
            if (count !== networks.length)
                doCadenceBodiesMatch = false;
        });
        if (!doCadenceBodiesMatch) {
            let mainnetTemplate = null;
            let testnetTemplate = null;
            if (cadence["mainnet"]) {
                const mainnetAddressByNetwork = new Map([...addressByNetwork].filter(([a, b]) => b.get("mainnet") !== undefined));
                mainnetTemplate = await constructInteractionTemplate(cadence.mainnet, transaction, identifier, ["mainnet"], mainnetAddressByNetwork);
            }
            if (cadence["testnet"]) {
                const testnetAddressByNetwork = new Map([...addressByNetwork].filter(([a, b]) => b.get("testnet") !== undefined));
                testnetTemplate = await constructInteractionTemplate(cadence.testnet, transaction, identifier, ["testnet"], testnetAddressByNetwork);
            }
            return {
                "mainnet": mainnetTemplate,
                "testnet": testnetTemplate
            };
        }
        const template = await constructInteractionTemplate(cadence.mainnet, transaction, identifier, networks, addressByNetwork);
        return template;
    }
    catch (e) {
        return null;
    }
}
exports.generateInteractionTemplate = generateInteractionTemplate;
