"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sign = exports.signMessage = exports.hashMsgHex = void 0;
const elliptic_1 = require("elliptic");
const sha3_1 = require("sha3");
const p256 = new elliptic_1.ec("p256");
const secp256 = new elliptic_1.ec("secp256k1");
// Takes in a msg that is already in hex form, and a
// hashAlg in flow's key format for hash algorithms
// Return binary digest
const hashMsgHex = (msgHex, hashAlg) => {
    if (hashAlg === "SHA3_256") {
        const sha = new sha3_1.SHA3(256);
        sha.update(Buffer.from(msgHex, "hex"));
        return sha.digest();
        // return crypto.createHash("sha3-256").update(msgHex).digest()
    }
    // if (hashAlg === "SHA2_256") {
    //   const md = forge.md.sha256.create();
    //   md.update(Buffer.from(msgHex, "hex").toString("utf8"), "utf8");
    //   return md.digest()
    //   // return crypto.createHash("sha256").update(msgHex).digest()
    // }
    throw new Error("Unsupported hash alg provided");
};
exports.hashMsgHex = hashMsgHex;
const signMessage = async (privateKey, sigAlg, hashAlg, msgHex) => {
    const ec = sigAlg === "ECDSA_P256" ?
        p256 :
        (sigAlg === "ECDSA_secp256k1" ?
            secp256 :
            null);
    if (!ec)
        throw new Error("Unsupported sig alg provided");
    const key = ec.keyFromPrivate(Buffer.from(privateKey, "hex"));
    const sig = key.sign((0, exports.hashMsgHex)(msgHex, hashAlg));
    const n = 32;
    const r = sig.r.toArrayLike(Buffer, "be", n);
    const s = sig.s.toArrayLike(Buffer, "be", n);
    return Buffer.concat([r, s]).toString("hex");
};
exports.signMessage = signMessage;
async function sign(privateKey, signAlgo, hashAlgo, msgHex) {
    return await (0, exports.signMessage)(privateKey, signAlgo, hashAlgo, msgHex);
}
exports.sign = sign;
