"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verify = exports.verifyMessage = void 0;
const tslib_1 = require("tslib");
const elliptic_1 = require("elliptic");
const node_crypto_1 = tslib_1.__importDefault(require("node:crypto"));
const p256 = new elliptic_1.ec("p256");
const secp256 = new elliptic_1.ec("secp256k1");
// Takes in a msg that is already in hex form, and a
// hashAlg in flow's key format for hash algorithms
// Return binary digest
const hashMsgHex = (msgHex, hashAlg) => {
    if (hashAlg === "SHA3_256") {
        // const sha = new SHA3(256);
        // sha.update(Buffer.from(msgHex, "hex"));
        // return sha.digest()
        return node_crypto_1.default.createHash("sha3-256").update(msgHex).digest();
    }
    if (hashAlg === "SHA2_256") {
        // const md = forge.md.sha256.create();
        // md.update(Buffer.from(msgHex, "hex").toString("utf8"), "utf8");
        // return md.digest()
        return node_crypto_1.default.createHash("sha256").update(msgHex).digest();
    }
    throw new Error("Unsupported hash alg provided");
};
const verifyMessage = async (publicKey, signature, sigAlg, hashAlg, msgHex) => {
    const ec = sigAlg === "ECDSA_P256" ?
        p256 :
        (sigAlg === "ECDSA_secp256k1" ?
            secp256 :
            null);
    console.log("msgHex", msgHex, "hashAlg", hashAlg, "sigAlg", sigAlg, "signature", signature);
    if (!ec)
        throw new Error("Unsupported sig alg provided");
    const key = ec.keyFromPublic(Buffer.from(publicKey, "hex"), "hex");
    console.log("msgHex", msgHex, "hashAlg", hashAlg, "signature", signature);
    const verified = key.verify(hashMsgHex(msgHex, hashAlg), signature);
    //   const n = 32;
    //   const r = sig.r.toArrayLike(Buffer, "be", n);
    //   const s = sig.s.toArrayLike(Buffer, "be", n);
    return verified;
};
exports.verifyMessage = verifyMessage;
async function verify(publicKey, signature, signAlgo, hashAlgo, data) {
    // const toVerifyHex = Buffer.from(data, "utf8").toString("hex")
    return await (0, exports.verifyMessage)(publicKey, signature, signAlgo, hashAlgo, data);
}
exports.verify = verify;
